What’s new in version 1.1.6
===========================
Version available since September 16th 2022


Bug fixed
---------
- bug caused by the plotXY function with optimizeParam.

Contributors
------------
Lucas Agobert
